from typing import TypedDict, Dict
from dataclasses import dataclass


class DeviceData(TypedDict):
    loungeStatus: str


class DeviceExpectations(TypedDict):
    screen_name: str
    screen_device_name: str
    device_info: dict


@dataclass
class Device:
    data: DeviceData
    expectations: DeviceExpectations


devices: Dict[str, Device] = {
    "LG OLED55C7V": Device(
        {
            "loungeStatus": {
                "devices": """[
                {
                    "app": "lb-v4",
                    "capabilities": "dsp,mic,dpa,ntb,que,mus",
                    "clientName": "tvhtml5",
                    "experiments": "",
                    "name": "YouTube on TV",
                    "theme": "cl",
                    "id": "xxxxxx-xxxx-xxx-xxx-xxxxxxx",
                    "type": "LOUNGE_SCREEN",
                    "hasCc": "true",
                    "deviceInfo": "{\\"brand\\":\\"LG\\",\\"model\\":\\"OLED55C7V-Z\\",\\"year\\":0,\\"os\\":\\"webOS\\",\\"osVersion\\":\\"2017\\",\\"chipset\\":\\"M16P\\",\\"clientName\\":\\"TVHTML5\\",\\"dialAdditionalDataSupportLevel\\":\\"full\\",\\"mdxDialServerType\\":\\"MDX_DIAL_SERVER_TYPE_SYSTEM\\"}",
                    "receiverIdentityMatchStatus": "IS_RECEIVER"
                },
                {
                    "app": "android-phone-18.16.34",
                    "pairingType": "dial",
                    "capabilities": "que,dsdtr,atp,mus",
                    "clientName": "android",
                    "deviceContext": "{\\"user_agent\\":\\"com.google.android.youtube\\\\/18.16.34(Linux; U; Android 13; en_GB; SM-G991B Build\\\\/TP1A.220624.014)\\",\\"window_width_points\\":360,\\"window_height_points\\":758,\\"os_name\\":\\"Android\\",\\"ms\\":\\"xxxxxxxxxxxxxxxx\\"}",
                    "experiments": "",
                    "name": "SAMSUNG SM-G991B",
                    "theme": "cl",
                    "id": "xxxxxxxxxx",
                    "type": "REMOTE_CONTROL",
                    "receiverIdentityMatchStatus": "MATCHES_RECEIVER"
                },
                {
                    "app": "web",
                    "pairingType": "unknown",
                    "capabilities": "que,dsdtr,atp,mus",
                    "clientName": "unknown",
                    "deviceContext": "user_agent=dunno&window_width_points=&window_height_points=&os_name=android&ms=",
                    "experiments": "",
                    "name": "Test",
                    "theme": "cl",
                    "id": "xxxxxxxxxxx",
                    "type": "REMOTE_CONTROL",
                    "localChannelEncryptionKey": "xxxxxxxxxxxxxxx",
                    "receiverIdentityMatchStatus": "DOES_NOT_MATCH_RECEIVER"
                }]"""
            }
        },
        {
            "screen_name": "YouTube on TV",
            "screen_device_name": "LG OLED55C7V-Z",
            "device_info": {
                "brand": "LG",
                "model": "OLED55C7V-Z",
                "year": 0,
                "os": "webOS",
                "osVersion": "2017",
                "chipset": "M16P",
                "clientName": "TVHTML5",
                "dialAdditionalDataSupportLevel": "full",
                "mdxDialServerType": "MDX_DIAL_SERVER_TYPE_SYSTEM",
            },
        },
    ),
    "Nintendo Switch": Device(
        {
            "loungeStatus": {
                "devices": """[
                    {
                    "app": "lb-v4",
                    "capabilities": "dsp,mic,dpa,ntb,vsp,que,mus",
                    "clientName": "tvhtml5",
                    "experiments": "",
                    "name": "Nintendo Switch",
                    "theme": "cl",
                    "id": "XXXXXXXXXXXXXXXXXXX",
                    "type": "LOUNGE_SCREEN",
                    "hasCc": "true",
                    "receiverIdentityMatchStatus": "IS_RECEIVER"
                }]"""
            }
        },
        {
            "screen_name": "Nintendo Switch",
            "screen_device_name": None,
            "device_info": None,
        },
    ),
}



import os
import sys

sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "../src")))

import pytest
import pyytlounge


@pytest.fixture
def wrapper():
    return pyytlounge.YtLoungeApi("Tester")



import pytest
from pyytlounge import YtLoungeApi
from .devices import Device, devices


@pytest.mark.parametrize("device", devices.values(), ids=devices.keys())
def test_event_loungeStatus(wrapper: YtLoungeApi, device: Device):
    wrapper._process_event(1, "loungeStatus", [device.data["loungeStatus"]])

    assert wrapper._screen_name == device.expectations["screen_name"]
    assert wrapper._device_info == device.expectations["device_info"]



#!/usr/bin/env python

import asyncio
import aiohttp
from api import api_base
async def get_screen(pairing_code):
    async with aiohttp.ClientSession() as session:
        async with session.post(f"{api_base}/pairing/get_screen", data={'pairing_code': pairing_code}) as response:
            return await response.json()
pairing_code = input("Enter manual pairing code as shown in YouTube app on target: ")
try:
    pairing_code = int(pairing_code)
except Exception as ex:
    print(f"Invalid pairing code {pairing_code}", ex)

# initial paring with code
loop = asyncio.get_event_loop()

screens = loop.run_until_complete(get_screen(pairing_code))
screen = screens["screen"]
screen_name = screen["name"]
screen_id = screen["screenId"]
lounge_token = screen["loungeToken"]

print(f"Found \"{screen_name}\" with id: '{screen_id}' token: '{lounge_token}'")

# refresh pairing from code
# res = requests.post(f"{api_base}/pairing/get_lounge_token_batch", data={'screen_ids': screen_id})

# print(f"Screen name {screen_name}, id: {screen_id}")
